- TestReport

# Test Report:

## Summary

START AT | 2019-03-06 19:19:20
DURATION | 0.014 seconds
PLATFORM | zybats 2.0.2.0 | CPython 3.7.0 | Windows-10-10.0.17134-SP0
STAT | TESTCASES (success/fail) | TESTSTEPS (success/fail/error/skip)
--- | --- | ---
total (details) => | 1 (0/1) | 3 (0/0/3/0)

## Details

### Shows how to use zybats ext api.

TOTAL: 3 | SUCCESS: 0 | FAILED: 0 | ERROR: 3 | SKIPPED: 0
Status | Name | Response Time | Detail
--- | --- | --- | ---
error | get token (setup) | N/A ms | log-1 ## Request and Response data × ### Name: get token (setup) ### Request:
url | "http://127.0.0.1:8080"/api/getTokenId
method | POST
headers | Content-Type: application/json
json | {'user_agent': 'iOS/10.3', 'device_sn': 'TESTCASE_SETUP_XXX', 'os_platform': 'ios', 'app_version': '2.8.6'}
verify | True
timeout | 120
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    zybats.exceptions.ParamsError: base url missed!
error | use redis ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.
error | use mysql ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.